API Documentation
=================

This is a complete list of available methods, along with details about them.

:mod:`fauxfactory`
------------------

.. automodule:: fauxfactory

:mod:`fauxfactory.factories.booleans`
-------------------------------------

.. automodule:: fauxfactory.factories.booleans
    :members:

:mod:`fauxfactory.factories.choices`
------------------------------------

.. automodule:: fauxfactory.factories.choices
    :members:

:mod:`fauxfactory.constants`
----------------------------

.. automodule:: fauxfactory.constants
    :members:

:mod:`fauxfactory.factories.dates`
----------------------------------

.. automodule:: fauxfactory.factories.dates
    :members:

:mod:`fauxfactory.helpers`
--------------------------

.. automodule:: fauxfactory.helpers
    :members:

:mod:`fauxfactory.factories.internet`
-------------------------------------

.. automodule:: fauxfactory.factories.internet
    :members:

:mod:`fauxfactory.factories.numbers`
------------------------------------

.. automodule:: fauxfactory.factories.numbers
    :members:

:mod:`fauxfactory.factories.strings`
------------------------------------

.. automodule:: fauxfactory.factories.strings
    :members:

:mod:`fauxfactory.factories.systems`
------------------------------------

.. automodule:: fauxfactory.factories.systems
    :members:
